@@ -308,8 +308,9 @@ def xToInt(value: str):
     return int(value, len(_xPar))
 
 
-def printTimestamp(timestamp: int | float):
-    print(time.strftime("%Y-%m-%d %H:%M:%S", time.localtime(timestamp)))
+def printTimestamp(timestamp: int | float, isLocal: bool = True):
+    structTime = isLocal and time.localtime(timestamp) or time.gmtime(timestamp)
+    print(time.strftime("%Y-%m-%d %H:%M:%S", structTime))
 
 
 # def scrapy(urlList, parseFun, extendSettings=None):
